// ExecuteCommandDlg.h
// (c) 2003-2005 exeal

#ifndef _EXECUTE_COMMAND_DLG_H_
#define _EXECUTE_COMMAND_DLG_H_
#include "resource.h"
#include "../Manah/Dialog.h"
#include "../Manah/DosCommand.h"


namespace Alpha {
	class CAlphaApp;

	///	[R}h̎s] _CAO
	class CExecuteCommandDlg :
			public Manah::Windows::Controls::CFixedIdDialog<IDD_DLG_EXECUTECOMMAND>,
			virtual public Manah::Windows::CDosCommand::ICommandEvent {
		// RXgN^
	public:
		CExecuteCommandDlg(CAlphaApp& app);

		// \bh
	public:
		// CDosCommand::ICommandEvent C^[tFCX
		virtual void	OnExit(Manah::Windows::CDosCommand::ExecuteStatus es);
		virtual void	OnReceiveOutput(const std::string& strOutput);

		// bZ[Wnh
	protected:
		virtual void	OnClose();												// WM_CLOSE
		virtual bool	OnCommand(WORD wID, WORD wNotifyCode, HWND hwndCtrl);	// WM_COMMAND
		virtual bool	OnInitDialog(HWND hwndFocus, LPARAM lInitParam);		// WM_INITDIALOG
		virtual void	OnCancel();												// IDCANCEL
		virtual void	OnOK();													// IDOK

		// f[^o
	public:
		bool	m_bHijackConsole;
		bool	m_bUseUnicode;
	private:
		CAlphaApp&					m_app;
		std::wstring				m_strCmdLine;
		Manah::Windows::CDosCommand	m_dosCommand;
		bool						m_bExecuting;	// R}hs
	};
}

#endif /* _EXECUTE_COMMAND_DLG_H_ */

/* [EOF] */